@@ -16,10 +16,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-#' EmpiricalCalibration
-#'
-#' @docType package
-#' @name EmpiricalCalibration
+#' @keywords internal
+"_PACKAGE"
+
 #' @import stats
 #' @importFrom grDevices rgb
 #' @importFrom utils read.csv
